import Card from '@/components/Card2.vue'
import * as api from '@/api/index'

export default {
  components: { Card },
  data() {
    return {
      list: [],
      loading: false,
      finished: false,
      pagination: { offset: 0, limit: 10 }
    }
  },
  watch: {
    '$route.query': {
      immediate: true,
      deep: true,
      handler(query) {
        if (!query.channel) {
          this.$dialog.alert({ message: '请选择事务' }).then(() => {
            this.$router.replace({ name: 'index', query })
          })
        }
      }
    }
  },
  computed: {
    channelId() {
      return this.$route.query.channel_id
    },
    channel() {
      const list = this.$store.state.affairTypes
      return list.find(item => item.id === this.channelId)
    },
    hasAdd() {
      return this.channel ? this.channel.close !== '1' : false
    }
  },
  methods: {
    getList() {
      const toast = this.$toast.loading({ message: '加载中...', forbidClick: true, duration: 0 })
      const params = Object.assign({ affair_id: this.channelId }, this.pagination)
      api
        .getAffairList(params)
        .then(response => {
          if (response.list.length) {
            this.list = this.list.concat(response.list)
          }
          this.loading = false
          this.finished = response.list.length < this.pagination.limit
          toast.clear()
        })
        .catch(() => {
          this.loading = false
          this.finished = true
          toast.clear()
        })
    },
    onLoad() {
      this.pagination.offset = this.pagination.offset + this.pagination.limit
      this.getList()
    },
    onRemove(data) {
      this.$dialog.confirm({ confirmButtonText: '确定', message: '确定要删除吗？' }).then(() => {
        api.deleteAffair(data.id).then(response => {
          if (response.success) {
            this.list = this.list.filter(item => item.id !== data.id)
          } else {
            this.$toast(response.message)
          }
        })
      })
    }
  },
  beforeMount() {
    this.getList()
  }
}
