import * as api from '../api'
export default {
  data() {
    const UA = window.navigator.userAgent
    const isMobile = /android|iphone|ipad|ipod/i.test(UA)
    return {
      isMobile,
      isWechat: isMobile && /micromessenger/i.test(UA),
      openId: window.localStorage.getItem('open_id')
    }
  },
  watch: {
    code: {
      immediate: true,
      handler(code) {
        if (code && !this.openId) {
          this.handlePay()
        }
      }
    },
    orderNo: {
      immediate: true,
      handler(orderNo) {
        orderNo && this.getOrder()
      }
    }
  },
  computed: {
    code() {
      return this.$route.query.code
    },
    orderNo() {
      const orderNo = this.$route.query.order_no
      return Array.isArray(orderNo) ? orderNo.pop() : orderNo
    }
  },
  methods: {
    // 创建微信订单
    createWxPayOrder(productId, num = 1) {
      const notifyUrl = `${location.origin}/api/ehall/v2/lobby/update-status-api/${this.pid}`
      return api
        .createWxpayOrder('ezijing', productId, { num, type: 7, openid: this.openId, notify_url: notifyUrl })
        .then(order => {
          const redirectURI = `${location.href}&order_no=${order.order_no}`
          // 去支付
          window.location.href = `https://web-pay.ezijing.com/wxpay/h5?prepay_id=${order.prepay_id}&open_id=${
            this.openId
          }&redirect_uri=${encodeURIComponent(redirectURI)}`
        })
    },
    // 获取微信code
    getCode() {
      const redirectURI = `https://pages.ezijing.com/given/auth.html?redirect_uri=${encodeURIComponent(location.href)}`
      window.location.href = `https://open.weixin.qq.com/connect/oauth2/authorize?appid=wx451c01d40d090d7a&redirect_uri=${redirectURI}&response_type=code&scope=snsapi_base#wechat_redirect`
    },
    // 获取微信openid
    getOpenId(callback) {
      if (!this.code) {
        this.getCode()
        return
      }
      api.getOpenId({ code: this.code, identity: 'ezijing' }).then(response => {
        if (response.code === 0) {
          this.openId = response.openid
          window.localStorage.setItem('open_id', this.openId)
          callback && callback(response)
        } else {
          this.getCode()
        }
      })
    },
    getOrder() {
      return api.getOrder(this.orderNo).then(response => {
        const { order } = response
        if (order.status === 1) {
          // 支付成功
          this.handlePaySuccess()
        }
        return order
      })
    },
    // 微信JSAPI支付
    handleWxJSAPIPay(productId, num) {
      this.openId
        ? this.createWxPayOrder(productId, num)
        : this.getOpenId(() => {
            this.createWxPayOrder(productId, num)
          })
    }
  }
}
