import Vue from 'vue'
import VueRouter from 'vue-router'
import Layout from '@/components/Layout.vue'
import RetateEdit from '@/views/retake/Edit.vue'
import ReportPaperEdit from '@/views/report/PaperEdit.vue'
import ReportElEdit from '@/views/report/ElEdit.vue'
import StudyContinueEdit from '@/views/study/ContinueEdit.vue'
import StudyPauseEdit from '@/views/study/PauseEdit.vue'
import CertSchoolyEdit from '@/views/cert/SchoolEdit.vue'
import CertStudyEdit from '@/views/cert/StudyEdit.vue'

Vue.use(VueRouter)

const routes = [
  { path: '*', redirect: '/' },
  { name: 'index', path: '/', component: () => import('@/views/Index.vue') },
  {
    name: 'login',
    path: '/login',
    component: () => import('@/views/Login.vue')
  },
  {
    path: '/list',
    component: Layout,
    children: [{ name: 'list', path: '', component: () => import('@/views/List.vue') }]
  },
  {
    path: '/create',
    component: Layout,
    children: [
      {
        name: 'create',
        path: '',
        component: () => import('@/views/Create.vue')
      }
    ]
  },
  {
    path: '/edit',
    component: Layout,
    children: [{ name: 'edit', path: '', component: () => import('@/views/Edit.vue') }]
  },
  {
    path: '/view',
    component: Layout,
    children: [{ name: 'view', path: '', component: () => import('@/views/View.vue') }]
  },
  // 重修
  {
    path: '/retake',
    component: Layout,
    children: [
      { name: 'retakeList', path: '', component: () => import('@/views/retake/List.vue') },
      { name: 'retakeAdd', path: 'add', component: RetateEdit },
      { name: 'retakeEdit', path: 'edit/:id', component: RetateEdit, props: { isEdit: true } },
      { name: 'retakeView', path: 'view/:id', component: () => import('@/views/retake/View.vue') }
    ]
  },
  // 纸质成绩单
  {
    path: '/report_papaer',
    component: Layout,
    children: [
      { name: 'reportPaperList', path: '', component: () => import('@/views/report/PaperList.vue') },
      { name: 'reportPaperAdd', path: 'add', component: ReportPaperEdit },
      { name: 'reportPaperEdit', path: 'edit/:id', component: ReportPaperEdit, props: { isEdit: true } },
      { name: 'reportPaperView', path: 'view/:id', component: () => import('@/views/report/PaperView.vue') }
    ]
  },
  // 电子成绩单
  {
    path: '/report_el',
    component: Layout,
    children: [
      { name: 'reportElList', path: '', component: () => import('@/views/report/ElList.vue') },
      { name: 'reportElAdd', path: 'add', component: ReportElEdit },
      { name: 'reportElEdit', path: 'edit/:id', component: ReportElEdit, props: { isEdit: true } },
      { name: 'reportElView', path: 'view/:id', component: () => import('@/views/report/ElView.vue') }
    ]
  },
  // 休学
  {
    path: '/study_pause',
    component: Layout,
    children: [
      { name: 'studyPauseList', path: '', component: () => import('@/views/study/PauseList.vue') },
      { name: 'studyPauseAdd', path: 'add', component: StudyPauseEdit },
      { name: 'studyPauseEdit', path: 'edit/:id', component: StudyPauseEdit, props: { isEdit: true } },
      { name: 'studyPauseView', path: 'view/:id', component: () => import('@/views/study/PauseView.vue') }
    ]
  },
  // 复学
  {
    path: '/study_continue',
    component: Layout,
    children: [
      { name: 'studyContinueList', path: '', component: () => import('@/views/study/ContinueList.vue') },
      { name: 'studyContinueAdd', path: 'add', component: StudyContinueEdit },
      { name: 'studyContinueEdit', path: 'edit/:id', component: StudyContinueEdit, props: { isEdit: true } },
      { name: 'studyContinueView', path: 'view/:id', component: () => import('@/views/study/ContinueView.vue') }
    ]
  },
  // Sofia在读证明
  {
    path: '/cert_shcool',
    component: Layout,
    children: [
      { name: 'certSchoolList', path: '', component: () => import('@/views/cert/SchoolList.vue') },
      { name: 'certSchoolAdd', path: 'add', component: CertSchoolyEdit },
      { name: 'certSchoolEdit', path: 'edit/:id', component: CertSchoolyEdit, props: { isEdit: true } },
      { name: 'certSchoolView', path: 'view/:id', component: () => import('@/views/cert/SchoolView.vue') }
    ]
  },
  // 紫荆在读证明
  {
    path: '/cert_study',
    component: Layout,
    children: [
      { name: 'certStudyList', path: '', component: () => import('@/views/cert/StudyList.vue') },
      { name: 'certStudyAdd', path: 'add', component: CertStudyEdit },
      { name: 'certStudyEdit', path: 'edit/:id', component: CertStudyEdit, props: { isEdit: true } },
      { name: 'certStudyView', path: 'view/:id', component: () => import('@/views/cert/StudyView.vue') }
    ]
  }
]

const router = new VueRouter({
  mode: 'history',
  base: process.env.BASE_URL,
  routes
})

export default router
